========================
 Invenio-Pages v1.0.0a4
========================

Invenio-Pages v1.0.0a4 was released on August 18, 2017.

About
-----

Static pages module for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Major refactoring for Invenio 3.
- Adds versioning support for pages.

Installation
------------

   $ pip install invenio-pages==1.0.0a4

Documentation
-------------

   https://invenio-pages.readthedocs.io/

Happy hacking and thanks for flying Invenio-Pages.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-pages
|   URL: http://inveniosoftware.org
